/* SPDX-License-Identifier: GPL-2.0-only */

#ifndef __MAINBOARD_GOOGLE_RAURU_PANEL_H__
#define __MAINBOARD_GOOGLE_RAURU_PANEL_H__

#include <soc/display.h>

#endif /* __MAINBOARD_GOOGLE_RAURU_PANEL_H__ */
